@@ -18,7 +18,7 @@ BEGIN {
 
 use Exporter ();
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-$VERSION   = '2.10_005';
+$VERSION   = '2.11_001';
 $VERSION   = eval $VERSION;
 @ISA       = qw(Exporter);
 @EXPORT    = qw(mkpath rmtree);
@@ -112,7 +112,7 @@ sub mkpath {
         for my $k (sort keys %{$arg}) {
             push @bad_args, $k unless $args_permitted{$k};
         }
-        _croak("Unrecognized option(s) passed to make_path(): @bad_args")
+        _carp("Unrecognized option(s) passed to make_path(): @bad_args")
             if @bad_args;
         $arg->{mode} = delete $arg->{mask} if exists $arg->{mask};
         $arg->{mode} = oct '777' unless exists $arg->{mode};
@@ -268,7 +268,7 @@ sub rmtree {
         for my $k (sort keys %{$arg}) {
             push @bad_args, $k unless $args_permitted{$k};
         }
-        _croak("Unrecognized option(s) passed to remove_tree(): @bad_args")
+        _carp("Unrecognized option(s) passed to remove_tree(): @bad_args")
             if @bad_args;
         ${ $arg->{error} }  = [] if exists $arg->{error};
         ${ $arg->{result} } = [] if exists $arg->{result};
@@ -344,7 +344,8 @@ sub _rmtree {
           : $root;
 
         my ( $ldev, $lino, $perm ) = ( lstat $root )[ 0, 1, 2 ]
-          or ( _error( $arg, "$root", $root ) and next ROOT_DIR );
+          or ( _error( $arg, "Cannot stat directory", $root ) and
+               next ROOT_DIR );
 
         if ( -d _ ) {
             $root = VMS::Filespec::vmspath( VMS::Filespec::pathify($root) )
@@ -576,8 +577,7 @@ File::Path - Create or remove directory trees
 
 =head1 VERSION
 
-This document describes version 2.09 of File::Path, released
-2013-01-17.
+This document describes version 2.11_001 of File::Path.
 
 =head1 SYNOPSIS
 
@@ -717,11 +717,14 @@ return value of the function is otherwise identical to make_path().
 
 The C<remove_tree> function deletes the given directories and any
 files and subdirectories they might contain, much like the Unix
-command C<rm -r> or the Windows commands C<rmdir /s> and C<rd /s>.
+command C<rm -r> or the Windows commands C<rmdir /s> and C<rd /s>. The
+only exception to the function similarity is C<remove_tree> accepts
+only directories whereas C<rm -r> also accepts files.
 
 The function accepts a list of directories to be
 removed. Its behaviour may be tuned by an optional hashref
-appearing as the last parameter on the call.
+appearing as the last parameter on the call.  If an empty string is
+passed to C<remove_tree>, an error will occur.
 
 The functions returns the number of files successfully deleted.
 
